'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Knex = _interopDefault(require('knex'));
var meyer = require('meyer');

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;
  subClass.__proto__ = superClass;
}

var MssqlDbms = /*#__PURE__*/function (_BaseDbms) {
  _inheritsLoose(MssqlDbms, _BaseDbms);

  function MssqlDbms(config) {
    var _this;

    _this = _BaseDbms.call(this) || this;

    _this.listMigrations = function (tableName) {
      try {
        return Promise.resolve(_this.knex.schema.hasTable(tableName)).then(function (_this$knex$schema$has) {
          function _temp2() {
            return Promise.resolve(_this.knex.table(tableName).select('id', 'name', 'up', 'down', 'checksum'));
          }

          var _temp = function () {
            if (!_this$knex$schema$has) {
              return Promise.resolve(new Promise(function (resolve, reject) {
                return _this.knex.schema.createTable(tableName, function (table) {
                  table.integer('id').primary().notNullable();
                  table.text('name').notNullable();
                  table.text('up').notNullable();
                  table.text('down').notNullable();
                  table.text('checksum').notNullable();
                }).then(resolve, reject);
              })).then(function () {});
            }
          }();

          return _temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp);
        });
      } catch (e) {
        return Promise.reject(e);
      }
    };

    _this.applyMigration = function (tableName, migration, opts) {
      try {
        return Promise.resolve(_this.knex.transaction(function (trx) {
          try {
            return Promise.resolve(trx.raw(migration.up)).then(function () {
              function _temp4() {
                return Promise.resolve(trx.table(tableName).insert(migration)).then(function () {});
              }

              var _temp3 = function () {
                if (opts.checkEffects) {
                  return Promise.resolve(trx.raw(migration.down)).then(function () {
                    return Promise.resolve(trx.raw(migration.up)).then(function () {});
                  });
                }
              }();

              return _temp3 && _temp3.then ? _temp3.then(_temp4) : _temp4(_temp3);
            });
          } catch (e) {
            return Promise.reject(e);
          }
        })).then(function () {});
      } catch (e) {
        return Promise.reject(e);
      }
    };

    _this.revertMigration = function (tableName, migration) {
      try {
        return Promise.resolve(_this.knex.transaction(function (trx) {
          try {
            return Promise.resolve(trx.raw(migration.down)).then(function () {
              return Promise.resolve(trx.table(tableName).where('id', migration.id)["delete"]()).then(function () {});
            });
          } catch (e) {
            return Promise.reject(e);
          }
        })).then(function () {});
      } catch (e) {
        return Promise.reject(e);
      }
    };

    _this.knex = Knex({
      client: 'mssql',
      connection: config,
      pool: {
        min: 0,
        max: 1,
        idleTimeoutMillis: 100,
        reapIntervalMillis: 100
      }
    });
    return _this;
  }

  return MssqlDbms;
}(meyer.BaseDbms);

exports.default = MssqlDbms;
//# sourceMappingURL=meyer-dbms-mssql.cjs.development.js.map
